document.addEventListener('DOMContentLoaded', () => {
    initializePredictions();
    initializeWallet();
});

function initializePredictions() {
    const cards = document.querySelectorAll('.prediction-card');
    
    cards.forEach(card => {
        // Simulate real-time price updates
        setInterval(() => {
            updatePrice(card);
            updatePrediction(card);
        }, 3000);
    });
}

function updatePrice(card) {
    const priceElement = card.querySelector('.current-price');
    const crypto = card.dataset.crypto;
    
    // Simulate price data
    const basePrice = crypto === 'BTC' ? 45000 : 3000;
    const randomChange = (Math.random() - 0.5) * 100;
    const newPrice = basePrice + randomChange;
    
    priceElement.textContent = newPrice.toFixed(2);
    animatePriceChange(priceElement, randomChange > 0);
}

function updatePrediction(card) {
    const predictionElement = card.querySelector('.prediction-value');
    const meterFill = card.querySelector('.meter-fill');
    
    // Simulate prediction algorithm
    const sentiment = Math.random();
    const width = sentiment * 100;
    
    meterFill.style.width = `${width}%`;
    predictionElement.textContent = sentiment > 0.5 ? 'Bullish' : 'Bearish';
    predictionElement.style.color = sentiment > 0.5 ? '#00ff00' : '#ff0000';
}

function animatePriceChange(element, isPositive) {
    element.style.color = isPositive ? '#00ff00' : '#ff0000';
    setTimeout(() => {
        element.style.color = 'white';
    }, 1000);
}

function initializeWallet() {
    const connectButton = document.querySelector('.connect-wallet');
    
    connectButton.addEventListener('click', async () => {
        if (typeof window.ethereum !== 'undefined') {
            try {
                await window.ethereum.request({ method: 'eth_requestAccounts' });
                connectButton.textContent = 'Connected';
                updateWalletUI();
            } catch (error) {
                console.error('User rejected connection');
            }
        } else {
            alert('Please install MetaMask to use wallet features');
        }
    });
}

function updateWalletUI() {
    const balanceElement = document.querySelector('.balance-amount');
    balanceElement.textContent = 'Loading...';
    
    // Simulate wallet balance update
    setTimeout(() => {
        const randomBalance = (Math.random() * 10).toFixed(4);
        balanceElement.textContent = `${randomBalance} ETH`;
    }, 1000);
}

// Add smooth scrolling for navigation
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
        e.preventDefault();
        document.querySelector(this.getAttribute('href')).scrollIntoView({
            behavior: 'smooth'
        });
    });
});